==> cms-db_v0.8.1.tar.gz: admin/editfile.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('files');
include('locale.inc.php');
$locale = new LocalizingClass('edit');
?>
<?php
if (isset($_POST['button']) && strpos($_POST['file'], '..') === false) {
	include('escape.inc.php');
	//START
	$filename = '../data/files'.$_POST['file'];
	$content = $_POST['content'];
	$content = escapeSL($content);
	if (is_writable($filename)) {

		if (!$handle = fopen($filename, "w")) {
			include('error.inc.php');
			throw_error(sprintf(locale('desc_error-open-file',true), $filename), 'editfile.php?file='.$_POST['file'].'&'.SID.csrf_protection_get());
		}

		if (!fwrite($handle, $content)) {
			include('error.inc.php');
			throw_error(sprintf(locale('desc_error-write-file',true), $filename), 'editfile.php?file='.$_POST['file'].'&'.SID.csrf_protection_get());
		}

		header('Location:files.php?path='.dirname($_POST['file']).'&'.SID.csrf_protection_get());

		fclose($handle);

	} else {
		include('error.inc.php');
		throw_error(sprintf(locale('desc_error-fileperms',true), $filename), 'editfile.php?file='.$_POST['file'].'&'.SID.csrf_protection_get());
	}
	//END
} else {
	$editmode = (isset($_GET['editmode'])) ? $_GET['editmode'] : 'text';
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_editfile') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
<script type="text/javascript">
<!--
function addPage(text) {
 //text = text.replace(/\//g,"%2F");
 //text = text.replace(/&/g,"&amp;");
 document.forms[0].content.value = document.forms[0].content.value+" "+text;
}
function addFile(text) {
 document.forms[0].content.value = document.forms[0].content.value+" "+text;
}
//-->
</script>
<noscript><?php locale('desc_javascript') ?></noscript>
<?php
include('../functions_url.inc.php');
if ($editmode == 'wysiwym') {
	include('wymeditor.inc.php');
} elseif ($editmode == 'text') {
	echo '<script type="text/javascript" src="jquery.js"></script>';
	echo '<script type="text/javascript" src="jquery.textarea.js"></script>';
	echo '<script type="text/javascript">$(function () { $("textarea").tabby(); });</script>';
} elseif ($editmode == 'syntax') {
	$codemirror_type = substr(strrchr($_GET['file'], '.'), 1);
	include('codemirror.inc.php');
}
?>
</head>
<body>

<h1><?php locale('title_editfile') ?></h1>
<p>
	<?php
	if ($editmode == 'text') {
		locale('link_editmode-text');
	} else {
		echo '<a class="nonewtab" href="editfile.php?file='.$_GET['file'].'&amp;editmode=text&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('link_editmode-text',true).'</a>';
	}
	$extensions = array('php', 'html', 'xml', 'js', 'css', 'py', 'lua', 'sql');
	$file_extension = substr(strrchr($_GET['file'], '.'), 1);
	if (in_array($file_extension, $extensions)) {
		echo ' | ';
		if ($editmode == 'syntax') {
			locale('link_editmode-syntax');
		} else {
			echo '<a class="nonewtab" href="editfile.php?file='.$_GET['file'].'&amp;editmode=syntax&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('link_editmode-syntax',true).'</a>';
		}
	}
	?>
</p>
<p>
	<form action="editfile.php?<?php echo SID; csrf_protection_get_html() ?>" method="post">
		<input type="hidden" name="wysiwym" value="<?php echo $wysiwym ?>" />
		<input type="hidden" name="file" value="<?php echo $_GET['file'] ?>" />
		<textarea class="wymeditor" id="content" name="content" cols="80" rows="20"><?php
include('getcontent.inc.php');
echo GetContent('../data/files'.$_GET['file']);
?></textarea><br />
		<div id="formbuttons">
			<input type="submit" name="button" value="<?php locale('button_save') ?>" class="wymupdate" />
		</div>
        </form>
</p>

</body>
</html>
<?php
}
?>

==> cms-db_v0.9.tar.gz: admin/editfile.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('files');
include('locale.inc.php');
$locale = new LocalizingClass('edit');
?>
<?php
if (isset($_POST['button']) && strpos($_POST['file'], '..') === false) {
	include('escape.inc.php');
	//START
	$filename = '../data/files'.$_POST['file'];
	$content = $_POST['content'];
	$content = escapeSL($content);
	if (is_writable($filename)) {

		if (!$handle = fopen($filename, "w")) {
			include('error.inc.php');
			throw_error(sprintf(locale('desc_error-open-file',true), $filename), 'editfile.php?file='.$_POST['file'].'&'.SID.csrf_protection_get());
		}

		if (!fwrite($handle, $content)) {
			include('error.inc.php');
			throw_error(sprintf(locale('desc_error-write-file',true), $filename), 'editfile.php?file='.$_POST['file'].'&'.SID.csrf_protection_get());
		}

		header('Location:files.php?path='.dirname($_POST['file']).'&'.SID.csrf_protection_get());

		fclose($handle);

	} else {
		include('error.inc.php');
		throw_error(sprintf(locale('desc_error-fileperms',true), $filename), 'editfile.php?file='.$_POST['file'].'&'.SID.csrf_protection_get());
	}
	//END
} else {
	$editmode = (isset($_GET['editmode'])) ? $_GET['editmode'] : 'text';
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_editfile') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
<script type="text/javascript">
<!--
function addPage(text) {
 //text = text.replace(/\//g,"%2F");
 //text = text.replace(/&/g,"&amp;");
 document.forms[0].content.value = document.forms[0].content.value+" "+text;
}
function addFile(text) {
 document.forms[0].content.value = document.forms[0].content.value+" "+text;
}
//-->
</script>
<noscript><?php locale('desc_javascript') ?></noscript>
<?php
include('../functions_url.inc.php');
if ($editmode == 'wysiwym') {
	include('wymeditor.inc.php');
} elseif ($editmode == 'text') {
	echo '<script type="text/javascript" src="jquery.js"></script>';
	echo '<script type="text/javascript" src="jquery.textarea.js"></script>';
	echo '<script type="text/javascript">$(function () { $("textarea").tabby(); });</script>';
} elseif ($editmode == 'syntax') {
	$codemirror_type = substr(strrchr($_GET['file'], '.'), 1);
	include('codemirror.inc.php');
}
?>
</head>
<body>

<h1><?php locale('title_editfile') ?></h1>

<form action="editfile.php?<?php echo SID; csrf_protection_get_html() ?>" method="post">
	<input type="hidden" name="file" value="<?php echo $_GET['file'] ?>" />
	<p class="linklist_action">
		<?php
		$cssclass = ($editmode == 'text') ? ' active' : '';
		echo '<a class="nonewtab'.$cssclass.'" href="editfile.php?file='.$_GET['file'].'&amp;editmode=text&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('link_editmode-text',true).'</a>';
		$extensions = array('php', 'html', 'xml', 'js', 'css', 'py', 'lua', 'sql', 'cs');
		$file_extension = substr(strrchr($_GET['file'], '.'), 1);
		if (in_array($file_extension, $extensions)) {
			$cssclass = ($editmode == 'syntax') ? ' active' : '';
			echo '<a class="nonewtab'.$cssclass.'" href="editfile.php?file='.$_GET['file'].'&amp;editmode=syntax&amp;'.SID.csrf_protection_get_html_ret().'">'.locale('link_editmode-syntax',true).'</a>';
		}
		?>
	</p>
	<div class="textarea <?php echo ($editmode == 'wysiwym' && !supportscontenteditable()) ? 'text' : $editmode ?>">
		<textarea class="wymeditor" id="content" name="content" cols="80" rows="20"><?php
		include('getcontent.inc.php');
		echo GetContent('../data/files'.$_GET['file']);
		?></textarea>
	</div>
	<p>
		<div id="formbuttons">
			<input type="submit" name="button" value="<?php locale('button_save') ?>" class="wymupdate" />
		</div>
	</p>
</form>

</body>
</html>
<?php
}
?>
